@@ -66,6 +66,7 @@ class Pipeline(ABC):
         self.set_spacy_language_model()
         self.pipe_stacks = None
         self.stack = []
+        self.spacy_n_processors = 1
 
     ############################################
     #####      ABSTRACT METHODS            #####
@@ -113,10 +114,9 @@ class Pipeline(ABC):
             logger.debug(f"executing component of type {s['type']} ")
             _component = s['component']
             if s['type'] == 'spacy':
-                nlp :Language = s['component']
-                logger.debug(type(nlp))
-                logger.debug(s['component'])
-                out = list(nlp.pipe(input, as_tuples=True, n_process=-1))
+                if self.spacy_n_processors != 1:
+                    logger.info(f"In case you are using transformer based pipe, set *spacy_n_processors* to 1 instead of {self.spacy_n_processors } or else the nlp.pipe will freeze")
+                out = list(s['component'].pipe(input, as_tuples=True, n_process=self.spacy_n_processors ))
                 input = out
             else:
                 out = _component(input)
@@ -130,7 +130,7 @@ class Pipeline(ABC):
         if self.annotated_artifacts is None:
             logger.error("Nothing to save, call annotate before saving")
             pass
-        for pipe in tqdm(self.pipeline):
+        for pipe in self.pipeline:
             if pipe.save_output:
                 logger.info("saving annotations of {}".format(pipe))
                 if self.out_df is None:
@@ -152,6 +152,7 @@ class Pipeline(ABC):
     def reset_input_output(self):
         self.set_input(None)
         self.annotated_artifacts = None
+        self.out_df = None
 
     def set_input(self, nodes):
         self.input = nodes
